@@ -46,6 +46,8 @@ $VERSION = "5.5";
      "ftp",
      "ftp_passive",
      "ftp_proxy",
+     "ftpstats_size",
+     "ftpstats_period",
      "getcwd",
      "gpg",
      "gzip",
@@ -74,6 +76,7 @@ $VERSION = "5.5";
      "pager",
      "password",
      "patch",
+     "patches_dir",
      "perl5lib_verbosity",
      "prefer_installer",
      "prefs_dir",
@@ -498,7 +501,9 @@ sub home () {
     my $old_v = $CPAN::Config->{load_module_verbosity};
     $CPAN::Config->{load_module_verbosity} = q[none];
     if ($CPAN::META->has_usable("File::HomeDir")) {
-        $home = File::HomeDir->my_data;
+        $home = File::HomeDir->can('my_dot_config')
+            ? File::HomeDir->my_dot_config
+                : File::HomeDir->my_data;
         unless (defined $home) {
             $home = File::HomeDir->my_home
         }
@@ -700,7 +705,7 @@ sub prefs_lookup {
     $VERSION = "5.5";
 
     # formerly CPAN::HandleConfig was known as CPAN::Config
-    sub AUTOLOAD {
+    sub AUTOLOAD { ## no critic
         my $class = shift; # e.g. in dh-make-perl: CPAN::Config
         my($l) = $AUTOLOAD;
         $CPAN::Frontend->mywarn("Dispatching deprecated method '$l' to CPAN::HandleConfig\n");
